==> nextcloud-app-mail-0.11.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/is.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Póstur",
    "Loading accounts" : "Hleð inn notendaaðgöngum",
    "Error while loading the accounts." : "Gat ekki lesið inn notandaaðganga..",
    "Can not load this folder." : "Gat ekki að hlaðið inn möppunni.",
    "Searching for {query}" : "Leita að {query}",
    "Error while deleting message." : "Villa kom upp við að eyða skilaboðum.",
    "Forwarded message" : "Áframsent skeyti",
    "Choose a folder to store the attachment in" : "Veldu möppu þar sem á að geyma viðhengið",
    "Attachments saved to Files." : "Viðhengi vistuð í skjalamöppu.",
    "Attachment saved to Files." : "Viðhengi vistað í skjalamöppu.",
    "Error while saving attachments to Files." : "Villa við að vista viðhengi í skjalamöppu.",
    "Error while saving attachment to Files." : "Villa við að vista viðhengi í skjalamöppu.",
    "Message flag could not be set." : "Ekki var ekki hægt að setja flagg á skilaboðin.",
    "Could not move message." : "Gat ekki flutt skilaboð.",
    "Invalid account" : "Ógildur aðgangur",
    "Invalid folder" : "Ógild mappa",
    "Error while creating the account: " : "Villa við að búa til notandaaðgang: ",
    "Unknown error" : "Óþekkt villa",
    "Error while updating the account: " : "Villa við að uppfæra notandaaðganginn",
    "All inboxes" : "Öll innhólf",
    "you" : "þú",
    "Send message to {email}" : "Senda skilaboð til {email}",
    "Could not load {tag}{name}{endtag}" : "Gat ekki hlaðið inn {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Vandamál kom upp við hlaða inn {tag}{name}{endtag}",
    "Could not load your message" : "Gat ekki hlaðið inn skilaboðunum þínum",
    "Could not load the desired message" : "Gat ekki hlaðið inn umbeðnum skilaboðum",
    "Could not load the message" : "Gat ekki hlaðið inn skilaboðunum",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ný skilaboð \nfrá {from}","%n ný skilaboð \nfrá {from}"],
    "Nextcloud Mail" : "Nextcloud-póstur",
    "Save" : "Vista",
    "Saved" : "Vistað",
    "Show all folders" : "Birta allar möppur",
    "Collapse folders" : "Fella möppur saman",
    "Error while deleting account." : "Villa kom upp við að eyða aðgangi.",
    "Choose a file to add as attachment" : "Veldu skrá til að setja sem viðhengi",
    "An error occurred while uploading {fname}" : "Villa kom upp við að senda inn {fname}",
    "Reply" : "Svara",
    "Send" : "Senda",
    "Sending …" : "Sendi ...",
    "Message sent!" : "Skilaboðin hafa verið send!",
    "Server error" : "Villa frá þjóni",
    "An unknown error occurred" : "Óþekkt villa kom upp",
    "Opening HTML drafts is not supported yet." : "Ekki er hægt að opna HTML-drög - ennþá.",
    "No writable calendars found" : "Engin skrifanleg dagatöl fundust",
    "Error while importing the calendar event" : "Villa kom upp við að flytja inn dagatalsatburðinn",
    "Error while downloading calendar event" : "Villa kom upp við að sækja dagatalsatburð",
    "& others" : "og aðrir",
    "Error while loading messages." : "Villa viðað hlaða inn skilaboðum.",
    "Error while refreshing messages." : "Villa kom upp við að endurlesa skilaboð.",
    "Setting up your account" : "Set upp aðganginn þinn",
    "Inbox" : "Innhólf",
    "Sent" : "Sent",
    "Drafts" : "Drög",
    "Archive" : "Skráasafn",
    "Trash" : "Rusl",
    "Junk" : "Ruslpóstur",
    "All" : "Allt",
    "Favorites" : "Eftirlæti",
    "Auto detect failed. Please use manual mode." : "Mistókst að finna sjálkrafa. Notaðu handvirku leiðina.",
    "Updating account failed: " : "Mistókst að uppfæra notandaaðgang: ",
    "Creating account failed: " : "Mistókst að búa til notandaaðgang: ",
    "Delete permanently" : "Eyða varanlega",
    "IMAP web client" : "IMAP vefforrit",
    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Einfalt og auðvelt tölvupóstforrit sem tengist póstþjóninum þínum með IMAP og SMTP.",
    "Error loading message" : "Villa við hleðslu á skilaboðum",
    "Settings" : "Stillingar",
    "Forwarding to %s" : "Áframsendi til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Smelltu hér ef þér er ekki beint áfram innan nokkurra sekúndna.",
    "Redirect" : "Endurbeina",
    "The link leads to %s" : "Tengillinn leiðir til %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ef þú vilt ekki fara á þá síðu, geturðu farið til baka í <a href=\"%s\">póstforritið</a>.",
    "Continue to %s" : "Halda áfram í %s",
    "Delete account" : "Eyða notandaaðgangi",
    "Try again" : "Reyndu aftur",
    "New message" : "Ný skilaboð",
    "Account Settings" : "Stillingar aðgangs",
    "Aliases" : "Samheiti",
    "Mail address" : "Tölvupóstfang",
    "Display Name" : "Birtingarnafn",
    "Account" : "Notandaaðgangur",
    "Toggle read" : "Víxla lesnu af/á",
    "Delete" : "Eyða",
    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
    "Speed up your Mail experience with these quick shortcuts." : "Flýttu fyrir vinnu þinni með póst með þessum flýtilyklum.",
    "Compose new message" : "Semja ný skilaboð",
    "Newer message" : "Nýrri skilaboð",
    "Older message" : "Eldri skilaboð",
    "Toggle star" : "Víxla stjörnumerkingu af/á",
    "Toggle unread" : "Víxla ólesnu af/á",
    "Search" : "Leita",
    "Refresh" : "Endurlesa",
    "Connect your mail account" : "Tengdu notandaaðganginn þinn",
    "Name" : "Nafn",
    "Mail Address" : "Tölvupóstfang",
    "Password" : "Lykilorð",
    "Manual configuration" : "Handvirk uppsetning",
    "IMAP Host" : "IMAP-vélarheiti",
    "IMAP security" : "IMAP-öryggi",
    "None" : "Ekkert",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-gátt",
    "IMAP User" : "IMAP-notandi",
    "IMAP Password" : "IMAP-lykilorð",
    "SMTP Host" : "SMTP-vélarheiti",
    "SMTP security" : "SMTP-öryggi",
    "SMTP Port" : "SMTP-gátt",
    "SMTP User" : "SMTP-notandi",
    "SMTP Password" : "SMTP-lykilorð",
    "Connect" : "Tengjast",
    "from" : "frá",
    "to" : "til",
    "cc" : "cc",
    "bcc" : "bcc",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Athugaðu að skilaboðin komu frá ekki-svara netfangi (noreply) þannig að svarið þitt verður líklega ekki lesið.",
    "Subject" : "Viðfangsefni",
    "Save all to Files" : "Vista allt í skrár",
    "Add mail account" : "Bæta við notandaaðgangi",
    "Use Gravatar and favicon avatars" : "Nota Gravatar og veftáknmyndir (favicon)",
    "No search results for" : "Engar leitarniðurstöður fyrir",
    "The images have been blocked to protect your privacy." : "Lokað hefur verið á myndir til að vernda einkalíf þitt.",
    "Show images from this sender" : "Birta myndir frá þessum sendanda",
    "Forward" : "Áframsenda",
    "No messages in this folder" : "Engin skilaboð í þessari möppu",
    "Upload attachment" : "Senda inn viðhengi",
    "Add attachment from Files" : "Bæta við viðhengi úr skrám",
    "Import into calendar" : "Flytja inn dagatal",
    "Download attachment" : "Sækja viðhengi",
    "Save to Files" : "Vista í skrár"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-app-mail-0.14.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/is.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Póstur",
    "Inbox" : "Innhólf",
    "Sent" : "Sent",
    "Drafts" : "Drög",
    "Archive" : "Skráasafn",
    "Trash" : "Rusl",
    "Junk" : "Ruslpóstur",
    "All" : "Allt",
    "Favorites" : "Eftirlæti",
    "Auto detect failed. Please use manual mode." : "Mistókst að finna sjálkrafa. Notaðu handvirku leiðina.",
    "Updating account failed: " : "Mistókst að uppfæra notandaaðgang: ",
    "Creating account failed: " : "Mistókst að búa til notandaaðgang: ",
    "Delete permanently" : "Eyða varanlega",
    "IMAP web client" : "IMAP vefforrit",
    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Einfalt og auðvelt tölvupóstforrit sem tengist póstþjóninum þínum með IMAP og SMTP.",
    "Auto" : "Sjálfvirkt",
    "Name" : "Nafn",
    "Mail Address" : "Tölvupóstfang",
    "Password" : "Lykilorð",
    "Manual" : "Handvirkt",
    "IMAP Settings" : "IMAP-stillingar",
    "IMAP Host" : "IMAP-vélarheiti",
    "IMAP Security" : "IMAP-öryggi",
    "None" : "Ekkert",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-gátt",
    "IMAP User" : "IMAP-notandi",
    "IMAP Password" : "IMAP-lykilorð",
    "SMTP Settings" : "SMTP-stillingar",
    "SMTP Host" : "SMTP-vélarheiti",
    "SMTP Security" : "SMTP-öryggi",
    "SMTP Port" : "SMTP-gátt",
    "SMTP User" : "SMTP-notandi",
    "SMTP Password" : "SMTP-lykilorð",
    "Save" : "Vista",
    "Connect" : "Tengjast",
    "Add mail account" : "Bæta við notandaaðgangi",
    "Use Gravatar and favicon avatars" : "Nota Gravatar og veftáknmyndir (favicon)",
    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
    "from" : "frá",
    "to" : "til",
    "+ cc/bcc" : "+ cc/bcc",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Viðfangsefni",
    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Athugaðu að skilaboðin komu frá ekki-svara netfangi\t(noreply) þannig að svarið þitt verður líklega ekki lesið.",
    "Message …" : "Skilaboð …",
    "Saving draft …" : "Vista drög …",
    "Draft saved" : "Drög vistuð",
    "Uploading attachments …" : "Sendi inn viðhengi…",
    "Sending …" : "Sendi ...",
    "Error sending your message" : "Villa við að senda skilaboðin þín",
    "Go back" : "Fara til baka",
    "Retry" : "Reyna aftur",
    "Message sent!" : "Skilaboðin hafa verið send!",
    "Reply sent!" : "Svar sent!",
    "Write another message" : "Skrifa önnur skilaboð",
    "Send" : "Senda",
    "Uploading {percent}% …" : "Sendi inn {percent}% …",
    "Upload attachment" : "Senda inn viðhengi",
    "Add attachment from Files" : "Bæta við viðhengi úr skrám",
    "Choose a file to add as attachment" : "Veldu skrá til að setja sem viðhengi",
    "No messages in this folder" : "Engin skilaboð í þessari möppu",
    "Draft: " : "Drög: ",
    "Mark read" : "Merkja sem lesið",
    "Mark unread" : "Merkja sem ólesið",
    "Delete" : "Eyða",
    "Report this bug" : "Tilkynna þessa villu",
    "Loading messages" : "Hleð inn skilaboðum",
    "Not found" : "Fannst ekki",
    "Could not load your message" : "Gat ekki hlaðið inn skilaboðunum þínum",
    "Import into calendar" : "Flytja inn dagatal",
    "Download attachment" : "Sækja viðhengi",
    "Save to Files" : "Vista í skrár",
    "Choose a folder to store the attachment in" : "Veldu möppu þar sem á að geyma viðhengið",
    "Save all to Files" : "Vista allt í skrár",
    "Choose a folder to store the attachments in" : "Veldu möppu þar sem á að geyma viðhengin",
    "The images have been blocked to protect your privacy." : "Lokað hefur verið á myndir til að vernda einkalíf þitt.",
    "Show images from this\tsender" : "Birta myndir frá þessum\tsendanda",
    "New message" : "Ný skilaboð",
    "Settings" : "Stillingar",
    "Edit" : "Breyta",
    "Show all folders" : "Birta allar möppur",
    "Collapse folders" : "Fella möppur saman",
    "Could not load your draft" : "Gat ekki hlaðið inn drögunum þínum",
    "No message selected" : "Engin skilaboð valin",
    "Signature" : "Undirskrift",
    "A signature will be added to the text of new and response messages." : "Undirskrift verður bætt við texta nýrra skilaboða og svarpósta.",
    "Account Settings" : "Stillingar aðgangs",
    "Mail server" : "Póstþjónn",
    "Speed up your Mail experience with these quick shortcuts." : "Flýttu fyrir vinnu þinni með póst með þessum flýtilyklum.",
    "Compose new message" : "Semja ný skilaboð",
    "Newer message" : "Nýrri skilaboð",
    "Older message" : "Eldri skilaboð",
    "Toggle star" : "Víxla stjörnumerkingu af/á",
    "Toggle unread" : "Víxla ólesnu af/á",
    "Search" : "Leita",
    "Refresh" : "Endurlesa",
    "Connect your mail account" : "Tengdu notandaaðganginn þinn",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ný skilaboð \nfrá {from}","%n ný skilaboð \nfrá {from}"],
    "Nextcloud Mail" : "Nextcloud-póstur",
    "All inboxes" : "Öll innhólf",
    "Could not load {tag}{name}{endtag}" : "Gat ekki hlaðið inn {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Vandamál kom upp við hlaða inn {tag}{name}{endtag}",
    "Could not load the desired message" : "Gat ekki hlaðið inn umbeðnum skilaboðum",
    "Could not load the message" : "Gat ekki hlaðið inn skilaboðunum",
    "Error loading message" : "Villa við hleðslu á skilaboðum",
    "Forwarding to %s" : "Áframsendi til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Smelltu hér ef þér er ekki beint áfram innan nokkurra sekúndna.",
    "Redirect" : "Endurbeina",
    "The link leads to %s" : "Tengillinn leiðir til %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ef þú vilt ekki fara á þá síðu, geturðu farið til baka í <a href=\"%s\">póstforritið</a>.",
    "Continue to %s" : "Halda áfram í %s"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
